intelmq.bots.collectors.mail package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.collectors.mail package

## Submodules

## intelmq.bots.collectors.mail.collector_mail_attach module

In Version 0.9.5 the attachment filename is no longer surrounded by double quotes, see for the discussion: https://github.com/certtools/intelmq/pull/1134 https://github.com/martinrusev/imbox/commit/7c6cc2fb5f7e39c1496d68f3d432eec19517bf8e#diff-1ae09572064c2e7c225de54ad5b49154

Uses the common mail iteration method from the lib file.

intelmq.bots.collectors.mail.collector_mail_attach.BOT

  alias of `intelmq.bots.collectors.mail.collector_mail_attach.MailAttachCollectorBot`

class intelmq.bots.collectors.mail.collector_mail_attach.MailAttachCollectorBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.bots.collectors.mail._lib.MailCollectorBot`

  Monitor IMAP mailboxes and retrieve mail attachments

  attach_regex: str = 'csv.zip'
  extract_files: bool = True
  folder: str = 'INBOX'
  init()
  mail_host: str = '<host>'
  mail_password: str = '<password>'
  mail_ssl: bool = True
  mail_user: str = '<user>'
  process_message(uid, message)
    Returns

      Mark the message as seen or not

    Return type

      seen

  rate_limit: int = 60
  subject_regex: str = '<subject>'

## intelmq.bots.collectors.mail.collector_mail_body module

Uses the common mail iteration method from the lib file.

intelmq.bots.collectors.mail.collector_mail_body.BOT

  alias of `intelmq.bots.collectors.mail.collector_mail_body.MailBodyCollectorBot`

class intelmq.bots.collectors.mail.collector_mail_body.MailBodyCollectorBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.bots.collectors.mail._lib.MailCollectorBot`

  Monitor IMAP mailboxes and fetch mail bodies

  content_types: Union[bool, str, Iterable[str]] = ('plain', 'html')
  folder: str = 'INBOX'
  init()
  mail_host: str = '<host>'
  mail_password: str = '<password>'
  mail_ssl: bool = True
  mail_user: str = '<user>'
  process_message(uid, message)
    Returns

      Mark the message as seen or not

    Return type

      seen

  rate_limit: int = 60
  subject_regex: str = '<subject>'

## intelmq.bots.collectors.mail.collector_mail_url module

Uses the common mail iteration method from the lib file.

intelmq.bots.collectors.mail.collector_mail_url.BOT

  alias of `intelmq.bots.collectors.mail.collector_mail_url.MailURLCollectorBot`

class intelmq.bots.collectors.mail.collector_mail_url.MailURLCollectorBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.bots.collectors.mail._lib.MailCollectorBot`, `intelmq.lib.mixins.http.HttpMixin`

  Monitor IMAP mailboxes and fetch files from URLs contained in mail bodies

  chunk_replicate_header: bool = True
  chunk_size: int = None
  folder: str = 'INBOX'
  http_password: str = None
  http_username: str = None
  init()
  mail_host: str = '<host>'
  mail_password: str = '<password>'
  mail_ssl: bool = True
  mail_user: str = '<user>'
  process_message(uid, message)
    Returns

      Mark the message as seen or not

    Return type

      seen

  rate_limit: int = 60
  ssl_client_certificate: str = None
  subject_regex: str = '<subject>'
  url_regex: str = 'http://'

## intelmq.bots.collectors.mail.lib module

## Module contents